summaryrefslogtreecommitdiffstats
path: root/kdbg/typetable.h
diff options
context:
space:
mode:
Diffstat (limited to 'kdbg/typetable.h')
-rw-r--r--kdbg/typetable.h76
1 files changed, 38 insertions, 38 deletions
diff --git a/kdbg/typetable.h b/kdbg/typetable.h
index 5cef561..0696675 100644
--- a/kdbg/typetable.h
+++ b/kdbg/typetable.h
@@ -4,10 +4,10 @@
* See the file COPYING in the toplevel directory of the source directory.
*/
-#include <qdict.h>
-#include <qstring.h>
-#include <qregexp.h>
-#include <qstringlist.h>
+#include <ntqdict.h>
+#include <ntqstring.h>
+#include <ntqregexp.h>
+#include <ntqstringlist.h>
#include <map>
class KConfigBase;
@@ -21,7 +21,7 @@ const int typeInfoMaxExpr = 5;
struct TypeInfo
{
- TypeInfo(const QString& displayString);
+ TypeInfo(const TQString& displayString);
~TypeInfo();
/**
@@ -35,13 +35,13 @@ struct TypeInfo
* between the percent signs '%' of the display expression; hence,
* there is one part more than there are sub-expressions.
*/
- QString m_displayString[typeInfoMaxExpr+1];
+ TQString m_displayString[typeInfoMaxExpr+1];
/**
* This is a list of partial expressions. Each contains one or more \%s,
* which will be replaced by the parent expression. The results are
* substituted for the percent signs in m_displayString.
*/
- QString m_exprStrings[typeInfoMaxExpr];
+ TQString m_exprStrings[typeInfoMaxExpr];
/**
* This is a list of guard expressions. Each contains one or more \%s,
* which will be replaced by the parent expression, or is empty. If the
@@ -49,14 +49,14 @@ struct TypeInfo
* corresponding expression from m_exprStrings is not evaluated. (This
* is used to guard function calls.)
*/
- QString m_guardStrings[typeInfoMaxExpr];
+ TQString m_guardStrings[typeInfoMaxExpr];
/**
* This is the type name including template arguments that contain a
* pattern: A single '*' as template parameter matches one template
* argument, except that a '*' as the last template parameter matches
* all remaining template argument.
*/
- QString m_templatePattern;
+ TQString m_templatePattern;
/**
* Returns a pointer to a TypeInfo that identifies wchar_t
*/
@@ -77,7 +77,7 @@ public:
TypeTable();
~TypeTable();
- typedef std::map<QString,TypeInfo*> TypeMap;
+ typedef std::map<TQString,TypeInfo*> TypeMap;
/**
* Load all known type libraries.
@@ -87,7 +87,7 @@ public:
/**
* Copy type infos to the specified dictionary.
*/
- void copyTypes(QDict<TypeInfo>& dict);
+ void copyTypes(TQDict<TypeInfo>& dict);
/**
* Returns the template types
@@ -97,34 +97,34 @@ public:
/**
* Does the file name match this library?
*/
- bool matchFileName(const QString& fileName) const {
+ bool matchFileName(const TQString& fileName) const {
return m_shlibNameRE.match(fileName) >= 0;
}
/**
* Is the specified builtin feature enabled in this type library?
*/
- bool isEnabledBuiltin(const QString& feature) const;
+ bool isEnabledBuiltin(const TQString& feature) const;
/**
* Returns the command to print the QString data.
*/
- const char* printQStringDataCmd() const { return m_printQStringDataCmd; }
+ const char* printTQStringDataCmd() const { return m_printTQStringDataCmd; }
protected:
/**
* Loads the structure type information from the configuration files.
*/
static void loadTypeTables();
- void loadFromFile(const QString& fileName);
- void readType(KConfigBase& cf, const QString& type);
- QDict<TypeInfo> m_typeDict;
- QDict<TypeInfo> m_aliasDict;
+ void loadFromFile(const TQString& fileName);
+ void readType(KConfigBase& cf, const TQString& type);
+ TQDict<TypeInfo> m_typeDict;
+ TQDict<TypeInfo> m_aliasDict;
TypeMap m_templates;
- QString m_displayName;
- QRegExp m_shlibNameRE;
- QStringList m_enabledBuiltins;
- char* m_printQStringDataCmd;
+ TQString m_displayName;
+ TQRegExp m_shlibNameRE;
+ TQStringList m_enabledBuiltins;
+ char* m_printTQStringDataCmd;
};
@@ -141,7 +141,7 @@ public:
/**
* Load types belonging to the specified libraries.
*/
- void loadLibTypes(const QStringList& libs);
+ void loadLibTypes(const TQStringList& libs);
/**
* Load types belonging to the specified type table
@@ -153,41 +153,41 @@ public:
*
* If the type is unknown, 0 is returned.
*/
- TypeInfo* lookup(QString type);
+ TypeInfo* lookup(TQString type);
/**
* Adds a new alias for a type name.
*/
- void registerAlias(const QString& name, TypeInfo* type);
+ void registerAlias(const TQString& name, TypeInfo* type);
/**
* Tells whether we use built-in support to understand QStrings.
*/
- bool parseQt2QStrings() const { return m_parseQt2QStrings; }
+ bool parseTQt2TQStrings() const { return m_parseTQt2TQStrings; }
/**
- * Tells whether QChar are defined like in Qt3.
+ * Tells whether TQChar are defined like in TQt3.
*/
bool qCharIsShort() const { return m_QCharIsShort; }
/**
* Returns the command to print the QString data.
*/
- const char* printQStringDataCmd() const { return m_printQStringDataCmd; }
+ const char* printTQStringDataCmd() const { return m_printTQStringDataCmd; }
protected:
- QDict<TypeInfo> m_types;
- QDict<TypeInfo> m_aliasDict;
+ TQDict<TypeInfo> m_types;
+ TQDict<TypeInfo> m_aliasDict;
struct TemplateInfo {
- QStringList templateArgs;
+ TQStringList templateArgs;
TypeInfo* type;
};
- typedef std::multimap<QString, TemplateInfo> TemplateMap;
+ typedef std::multimap<TQString, TemplateInfo> TemplateMap;
TemplateMap m_templates; //!< one or more template patterns per template name
static TemplateMap::value_type
template2Info(const TypeTable::TypeMap::value_type& tt);
- static QStringList splitTemplateArgs(const QString& t);
- bool m_parseQt2QStrings;
+ static TQStringList splitTemplateArgs(const TQString& t);
+ bool m_parseTQt2TQStrings;
bool m_QCharIsShort;
- const char* m_printQStringDataCmd;
+ const char* m_printTQStringDataCmd;
};
@@ -97,34 +97,34 @@ public:
/**
- * Returns the command to print the QString data.
+ * Returns the command to print the TQString data.
*/
@@ -153,41 +153,41 @@ public:
/**
- * Tells whether we use built-in support to understand QStrings.
+ * Tells whether we use built-in support to understand TQStrings.
*/
@@ -153,41 +153,41 @@ public:
bool qCharIsShort() const { return m_QCharIsShort; }
/**
- * Returns the command to print the QString data.
+ * Returns the command to print the TQString data.
*/